@@ -136,11 +136,11 @@ def parse_ratelimit_headers(headers: Mapping[str, str]) -> Optional[RateLimitInf
     )
 
 
-# Both headers are used by the Hub to debug failed requests.
-# `X_AMZN_TRACE_ID` is better as it also works to debug on Cloudfront and ALB.
-# If `X_AMZN_TRACE_ID` is set, the Hub will use it as well.
-X_AMZN_TRACE_ID = "X-Amzn-Trace-Id"
+# When raising an error, we include the request id in the error message for easier debugging.
+# Request ID is sourced from headers in order of precedence: "X-Request-Id", "X-Amzn-Trace-Id", "X-Amz-Cf-Id".
 X_REQUEST_ID = "x-request-id"
+X_AMZN_TRACE_ID = "X-Amzn-Trace-Id"
+X_AMZ_CF_ID = "x-amz-cf-id"
 
 REPO_API_REGEX = re.compile(
     r"""
@@ -843,15 +843,22 @@ def _format(error_type: type[HfHubHTTPError], custom_message: str, response: htt
             final_error_message += "\n" + server_message
         else:
             final_error_message += "\n\n" + server_message
+
+    # Prepare Request ID message
+    request_id = ""
+    request_id_message = ""
+    for header, label in (
+        (X_REQUEST_ID, "Request ID"),
+        (X_AMZN_TRACE_ID, "Amzn Trace ID"),
+        (X_AMZ_CF_ID, "Amz CF ID"),
+    ):
+        value = response.headers.get(header)
+        if value:
+            request_id = str(value)
+            request_id_message = f" ({label}: {value})"
+            break
+
     # Add Request ID
-    request_id = str(response.headers.get(X_REQUEST_ID, ""))
-    if request_id:
-        request_id_message = f" (Request ID: {request_id})"
-    else:
-        # Fallback to X-Amzn-Trace-Id
-        request_id = str(response.headers.get(X_AMZN_TRACE_ID, ""))
-        if request_id:
-            request_id_message = f" (Amzn Trace ID: {request_id})"
     if request_id and request_id.lower() not in final_error_message.lower():
         if "\n" in final_error_message:
             newline_index = final_error_message.index("\n")
